@@ -102,6 +102,24 @@ def word_list_id(*args):
     raise TypeError("Invalid arguments to the WordListId constructor")
 
 
+class DefaultTemplate:
+    def __init__(self, person, plural, gender, template):
+        self.person = person
+        self.plural = plural
+        self.gender = gender
+        self.template = template
+
+    def _score(self, mine, theirs):
+        if mine == theirs:
+            return 10
+        elif mine is None or theirs is None:
+            return 1
+        return 0
+
+    def match(self, person, plural, gender):
+        return self._score(self.person, person) + self._score(self.plural, plural) + self._score(self.gender, gender)
+
+
 class Insulter(object):
     """!
     Object that can generate insults
@@ -113,6 +131,8 @@ class Insulter(object):
     regex_word_file = re.compile(r'^[a-z_]+$')
     ## File name for language rules
     rules_file = "rules.json"
+    ## File name for default templates
+    defaults_file = "defaults.json"
 
     def __init__(self):
         """!
@@ -125,6 +145,8 @@ class Insulter(object):
         self.list_max_count = {}
         ## Language rules
         self.rules = {}
+        ## Default templates
+        self.templates = []
 
     def word_list(self, wl_id, add=False):
         """!
@@ -160,11 +182,34 @@ class Insulter(object):
                         self.set_rules(name, rule)
                 except ValueError:
                     pass
+            elif basename == Insulter.defaults_file:
+                try:
+                    with open(full) as file:
+                        defaults = json.load(file)
+                    for rule in defaults:
+                        self.templates.append(DefaultTemplate(
+                            rule.get("person", None), rule.get("plural", None), rule.get("gender", None), rule["template"]
+                        ))
+                except ValueError:
+                    pass
             elif os.path.isfile(full) and self.regex_word_file.match(basename):
                 with open(full) as file:
                     lines = list(filter(bool, (line.strip() for line in file)))
                 self.add_words(basename, lines)
 
+    def default_template(self, person, plural, gender):
+        """
+        Returns the best default template for the given person
+        """
+        best = None
+        best_score = -1
+        for template in self.templates:
+            score = template.match(person, plural, gender)
+            if score > best_score:
+                best_score = score
+                best = template.template
+        return best
+
     def add_words(self, wl_id, words):
         """!
         Adds words to a word list
@@ -191,7 +236,7 @@ class Insulter(object):
             max_count = self.list_max_count[wl_id.name]
         return self.word_list(wl_id).get(max_count, min_count)
 
-    def format(self, string):
+    def format(self, string, custom_expansions={}):
         """!
         Formats an insult string
         """
@@ -208,11 +253,11 @@ class Insulter(object):
             unexpanded = new_unexpanded
             new_unexpanded = []
             for elem in unexpanded:
-                if not self._expand_element(elem, doc):
+                if not self._expand_element(elem, doc, custom_expansions):
                     new_unexpanded.append(elem)
         return str(doc)
 
-    def _expand_element(self, element, doc):
+    def _expand_element(self, element, doc, custom_expansions):
         try:
             if element.tag_name in self.rules:
                 return self._expand_rule(element, doc)
@@ -226,6 +271,9 @@ class Insulter(object):
             element._expansion = " ".join(self.get(element.tag_name, max, min))
             return True
         except Exception:
+            if element.tag_name in custom_expansions:
+                element._expansion = custom_expansions[element.tag_name]
+                return True
             return False
 
     def _expand_rule(self, element, doc):
